@@ -20,7 +20,6 @@ def get_custom_objects():
 
 class WrapCodeComponent(Component):
     def __init__(self,
-                 name,
                  head_num,
                  hidden_dim,
                  attention_activation=None,
@@ -36,7 +35,7 @@ class WrapCodeComponent(Component):
                  *args,
                  **kwargs
                  ):
-        super(WrapCodeComponent, self).__init__(name=name)
+        super(WrapCodeComponent, self).__init__()
         self.head_num = head_num
         self.hidden_dim = hidden_dim
         self.attention_activation = attention_activation
@@ -58,7 +57,7 @@ class WrapCodeComponent(Component):
 
         kwargs['trainable'] = self.trainable
 
-        super(WrapCodeComponent, self).__init__(name=name, *args, **kwargs)
+        super(WrapCodeComponent, self).__init__(*args, **kwargs)
 
     def build(self, input_shape):
         if self.use_attention:
